stm32-metapac

Crates

git

Versions

stm32h7r7a8

Flavors

Opfccr

Struct Opfccr 

#[repr(transparent)]
pub struct Opfccr(pub u32);
DMA2D output PFC control register

Tuple Fields

0: u32

Implementations



impl Opfccr

pub const fn cm(&self) -> OpfccrCm

Color mode. These bits define the color format of the output image. These bits can only be written when data transfers are disabled. Once the transfer has started, they are read-only. others: meaningless

pub const fn set_cm(&mut self, val: OpfccrCm)

Color mode. These bits define the color format of the output image. These bits can only be written when data transfers are disabled. Once the transfer has started, they are read-only. others: meaningless

pub const fn sb(&self) -> Sb

Swap Bytes

pub const fn set_sb(&mut self, val: Sb)

Swap Bytes

pub const fn ai(&self) -> OpfccrAi

Alpha inverted. This bit inverts the alpha value. Once the transfer has started, this bit is read-only.

pub const fn set_ai(&mut self, val: OpfccrAi)

Alpha inverted. This bit inverts the alpha value. Once the transfer has started, this bit is read-only.

pub const fn rbs(&self) -> OpfccrRbs

Red blue swap. This bit allows to swap the R and B to support BGR or ABGR color formats. Once the transfer has started, this bit is read-only.

pub const fn set_rbs(&mut self, val: OpfccrRbs)

Red blue swap. This bit allows to swap the R and B to support BGR or ABGR color formats. Once the transfer has started, this bit is read-only.